// Include Libraries
#include <stdio.h>
#include <stdlib.h>

// Please check dxfout.h for function parameter definitions
#include "dxfout.h"

#include "ezxdisp.h"
// -lezx -lX11 -lm             for Linux
// -lmingw32 -lezx -mwindows   for windows (MinGW)

// EZX display structure
ezx_t *disp;

// EZX window size
int width=1200;
int height=700;

// Nominal display scale
double scale=10.0;

int main(int argc,char **argv) {
  printf("DXFOut V1.1 - Written by Alan Cooper (AlanCooper@StartMail.com)\n");

  // Open a new DXF file
  char fileName[128];
  sprintf(fileName,"DXFOutTest.dxf");
  FILE *F1=fopen(fileName,"w");

  // Initialise graphics
  disp=ezx_init(width,height,"Show DXF");
  ezx_set_background(disp,&ezx_black);

  // Create a small box:
  //   Use Shape (closed polyline)
  //   Set Colour 0
  //   Set Layer "Test"
  //   Note: Z coordinate is 0
  DXF_Begin(F1);                        // Required once
  DXF_ShapeBegin(F1,"Test",0);          // Required for each shape (closed polyline)
  DXF_ShapePoint(F1,10,30,0);
  DXF_ShapePoint(F1,30,30,0);
  ezx_line_2d(disp,width/2+scale*10,height/2-scale*30,width/2+scale*30,height/2-scale*30,&ezx_white,1);
  DXF_ShapePoint(F1,30,10,0);
  ezx_line_2d(disp,width/2+scale*30,height/2-scale*30,width/2+scale*30,height/2-scale*10,&ezx_white,1);
  DXF_ShapePoint(F1,10,10,0);
  ezx_line_2d(disp,width/2+scale*30,height/2-scale*10,width/2+scale*10,height/2-scale*10,&ezx_white,1);
  ezx_line_2d(disp,width/2+scale*10,height/2-scale*10,width/2+scale*10,height/2-scale*30,&ezx_white,1);
  DXF_ShapeEnd(F1);                     // Required for each shape (closed polyline)

  // Put a point in the middle
  DXF_Point(F1,"Test",1,20,20,0);
  ezx_point_2d(disp,width/2+scale*(20),height/2-scale*(20),&ezx_red);

  // Make point look like a cross-hair using lines
  DXF_Line(F1,"Test",2,22,20,0,25,20,0);
  ezx_line_2d(disp,width/2+scale*22,height/2-scale*20,width/2+scale*25,height/2-scale*20,&ezx_yellow,1);
  DXF_Line(F1,"Test",2,18,20,0,15,20,0);
  ezx_line_2d(disp,width/2+scale*18,height/2-scale*20,width/2+scale*15,height/2-scale*20,&ezx_yellow,1);
  DXF_Line(F1,"Test",2,20,22,0,20,25,0);
  ezx_line_2d(disp,width/2+scale*20,height/2-scale*22,width/2+scale*20,height/2-scale*25,&ezx_yellow,1);
  DXF_Line(F1,"Test",2,20,18,0,20,15,0);
  ezx_line_2d(disp,width/2+scale*20,height/2-scale*18,width/2+scale*20,height/2-scale*15,&ezx_yellow,1);

  // Put a circle around the cross-hair
  DXF_Circle(F1,"Test",3,20,20,0,5);
  ezx_circle_2d(disp,width/2+scale*20,height/2-scale*20,scale*5,&ezx_green,1);


  // And another box but using polyline (open polyline)
  DXF_PolylineBegin(F1,"Test",4);       // Required for each shape (closed polyline)
  DXF_PolylinePoint(F1, 9,31,0);
  DXF_PolylinePoint(F1,31,31,0);
  ezx_line_2d(disp,width/2+scale*9,height/2-scale*31,width/2+scale*31,height/2-scale*31,&ezx_cyan,1);
  DXF_PolylinePoint(F1,31, 9,0);
  ezx_line_2d(disp,width/2+scale*31,height/2-scale*31,width/2+scale*31,height/2-scale*9,&ezx_cyan,1);
  DXF_PolylinePoint(F1, 9, 9,0);
  ezx_line_2d(disp,width/2+scale*31,height/2-scale*9,width/2+scale*9,height/2-scale*9,&ezx_cyan,1);
    DXF_PolylinePoint(F1, 9,31,0); // Close the box
  ezx_line_2d(disp,width/2+scale*9,height/2-scale*9,width/2+scale*9,height/2-scale*31,&ezx_cyan,1);
  DXF_PolylineEnd(F1);                  // Required for each shape (closed polyline)

  DXF_End(F1);                          // Required once

  // Show the display and wait for exit
  ezx_redraw(disp);
  while (!ezx_isclosed(disp));
  ezx_quit(disp);

  // Close the DXF file
  fclose(F1);

  return 0;
}
